Function xshell::pushenv [−][src]
pub fn pushenv(key: impl AsRef<OsStr>, val: impl AsRef<OsStr>) -> Pushenv
Sets the environment variable key to have value val.
Returns a Pushenv value that, when dropped, will reset the the
environment variable key to whatever value it had right before the call to
pushenv that produced that Pushenv.