Struct TempDir

struct TempDir { ... }

A temporary directory.

This is a RAII object which will remove the underlying temporary directory when dropped.

Implementations

impl TempDir

fn path(self: &Self) -> &Path

Returns the path to the underlying temporary directory.

impl Debug for TempDir

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Drop for TempDir

fn drop(self: &mut Self)

impl Freeze for TempDir

impl RefUnwindSafe for TempDir

impl Send for TempDir

impl Sync for TempDir

impl Unpin for TempDir

impl UnsafeUnpin for TempDir

impl UnwindSafe for TempDir

impl<T> Any for TempDir

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TempDir

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TempDir

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for TempDir

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for TempDir

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TempDir

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TempDir

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>