Type Alias Result
type Result = Result<T, E>
Result from std, with the error type defaulting to xshell's Error.
Resulttype Result = Result<T, E>
Result from std, with the error type defaulting to xshell's Error.